@@ -1,4 +1,4 @@
-import datetime,builtins,platform,time,math,os,urllib,sys
+import datetime,builtins,platform,time,math,os,urllib,sys,hashlib
 from urllib import request
 dicts={}
 IS_WIN=False if platform.system().find('Linux')>-1 else True
@@ -42,7 +42,7 @@ def diff(a,b):
 def notice(x,c='default'):request.urlopen(r'http://call.ff2.pw/?%s=%s&passwd=frank'%(c,urllib.parse.quote_plus(x)))
 def rand_sleep(i=0.4,a=0.8):import random;time.sleep(random.randint(i*1000,a*1000)/1000);
 def rand(i=9,a=None):import random;return random.randint(int(i),int(a)) if a else random.randint(0,int(i-1));
-def md5(x):import hashlib;hl = hashlib.md5();hl.update(x.encode('utf-8') if isinstance(x,str) else x);return hl.hexdigest();
+def md5(x):hl = hashlib.md5();hl.update(x.encode('utf-8') if isinstance(x,str) else x);return hl.hexdigest();
 def bin2hex(x):import binascii;return binascii.hexlify(x.encode('utf-8') if isinstance(x,str) else x);
 def base64_encode(x):import base64;return base64.b64encode(x) if isinstance(x,bytes) else base64.b64encode(x.encode('utf-8'))
 def base64_decode(x):import base64;return base64.b64decode(x)
@@ -77,6 +77,39 @@ def obj(obj=None,remote=False,name:str =None,expire:(str,int)=None):
 					os.remove(path)
 					return None
 			return pickle.dump(obj,open(path,'wb'))
+def encrypt(string,password=None):
+	first_letter=string[0]
+	hl = hashlib.sha512()
+	hl.update(first_letter.encode('utf-8')if password is None else password.encode('utf-8'))
+	sha512=hl.digest()
+	_= sha512[0]%64
+	sha512=(sha512[_:]+sha512[:_])*math.ceil(len(string)/64)
+	encrypted=''
+	for i,x in enumerate(string):
+		encrypted+=chr((ord(x)+sha512[i])%94+33)
+	if password is None:
+		encrypted=chr((ord(first_letter)+ord(encrypted[-1]))%94+33)+encrypted[1:]
+	return encrypted
+def decrypt(string,password=None):
+	hl = hashlib.sha512()
+	if not password:
+		for i in range(6):
+			_=94*i+ord(string[0])-(ord(string[-1])+33)
+			if _ >=33 and _<127:break
+		first_letter=chr(_)
+	hl.update(first_letter.encode('utf-8')if password is None else password.encode('utf-8'))
+	sha512=hl.digest()
+	_= sha512[0]%64
+	sha512=(sha512[_:]+sha512[:_])*math.ceil(len(string)/64)
+	decrypted=''
+	for i,x in enumerate(string):
+		for ii in range(6):
+			_=94*ii+ord(x)-(sha512[i]+33)
+			if _ >=33 and _<127:break
+		decrypted+=chr(_)
+	if password is None:
+		decrypted=first_letter+decrypted[1:]
+	return decrypted
 class mysql(object):
 	conn=None
 	def __init__(self, host='127.0.0.1',**args):
